summaryrefslogtreecommitdiff
path: root/gtk/gtkmessagedialog.c
diff options
context:
space:
mode:
authorMatthias Clasen <mclasen@redhat.com>2016-07-12 21:57:46 -0400
committerMatthias Clasen <mclasen@redhat.com>2016-07-12 21:58:11 -0400
commit500c9dbe96d56895a95b6594c6ab5f011c747e3f (patch)
tree61e0eaa3140c052a042e04d3de7f09b1957db6b8 /gtk/gtkmessagedialog.c
parent8f1fd7d964c4d447253a2317caa7929a8ee0fabf (diff)
downloadgtk+-500c9dbe96d56895a95b6594c6ab5f011c747e3f.tar.gz
Remove a few mentions of GtkVBox in the docs
We only have GtkBox nowadays.
Diffstat (limited to 'gtk/gtkmessagedialog.c')
-rw-r--r--gtk/gtkmessagedialog.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gtk/gtkmessagedialog.c b/gtk/gtkmessagedialog.c
index ae6f5e57d0..e70c82056c 100644
--- a/gtk/gtkmessagedialog.c
+++ b/gtk/gtkmessagedialog.c
@@ -292,7 +292,7 @@ gtk_message_dialog_class_init (GtkMessageDialogClass *class)
PROP_MESSAGE_AREA,
g_param_spec_object ("message-area",
P_("Message area"),
- P_("GtkVBox that holds the dialog's primary and secondary labels"),
+ P_("GtkBox that holds the dialog's primary and secondary labels"),
GTK_TYPE_WIDGET,
GTK_PARAM_READABLE));
@@ -914,7 +914,7 @@ gtk_message_dialog_format_secondary_markup (GtkMessageDialog *message_dialog,
* See gtk_dialog_get_content_area() for the corresponding
* function in the parent #GtkDialog.
*
* Returns: (transfer none): A #GtkVBox corresponding to the
* “message area” in the @message_dialog.
*
* Since: 2.22
@@ -914,7 +914,7 @@ gtk_message_dialog_format_secondary_markup (GtkMessageDialog *message_dialog,
* function in the parent #GtkDialog.
*
- * Returns: (transfer none): A #GtkVBox corresponding to the
+ * Returns: (transfer none): A #GtkBox corresponding to the
* “message area” in the @message_dialog.
*